@@ -9,24 +9,25 @@ sub BUILD {
   my $self=shift;
   my $au_sts;
   my $challenge;
+  my $res;
 
   #Get API version if we're called first
   $self->api_version;
   
   unless ( $self->app_token and $self->track_id ) {
     #Request token 
-    $self->req_auth ( { app_id => $self->app_id, 
-                      app_name => $self->app_name, 
-                      app_version => $self->app_version, 
-                      device_name => $self->device_name } );
-     $self->track_id( $self->uar->{result}{track_id} );
-     $self->app_token( $self->uar->{result}{app_token} ); 
+    $res = $self->req_auth ( {   app_id => $self->app_id, 
+                               app_name => $self->app_name, 
+                            app_version => $self->app_version, 
+                            device_name => $self->device_name } );
+     $self->track_id( $res->{track_id} );
+     $self->app_token( $res->{app_token} ); 
   }
 
   #Check auth status or wait for physical granting on the device
-  $self->auth_progress( $self->track_id );
-  while( ( $au_sts = $self->uar->{result}{status} ) eq "pending" ) { 
-    $challenge = $self->uar->{result}{challenge};
+  $res = $self->auth_progress( $self->track_id );
+  while( ( $au_sts = $res->{status} ) eq "pending" ) { 
+    $challenge = $res->{challenge};
     print "Please Confirm on the FB - Merci d'autoriser sur la FB\n";
     $self->auth_progress( $self->track_id );
     sleep 1;
@@ -34,18 +35,15 @@ sub BUILD {
 
   die "Authorization not granted($au_sts)" unless $au_sts eq "granted";
 
-  unless ($challenge) {
-    $self->login;
-    $challenge = $self->uar->{result}{challenge};
-  }
+  $challenge = $self->login->{challenge} unless ($challenge);
 
-  $self->open_session( {
+  $res = $self->open_session( {
       app_id =>  $self->app_id, 
       app_version => $self->app_version, 
       password => hmac_sha1_hex( $challenge, $self->app_token ),
   } );
   
-  $self->ua->default_header('X-Fbx-App-Auth' => $self->uar->{result}{session_token});
+  $self->ua->default_header('X-Fbx-App-Auth' => $res->{session_token});
 
 }
 
